{% if nav_item.is_page %}
<li class="nav-page">
	<a class="noselect" href="{{ base_url }}/{{ nav_item.url }}">{{ nav_item.title }}</a>
</li>
{% endif %}

{% if nav_item.is_section %}
<li id="section" class="section noselect">
	<span>{{ nav_item.title }}</span>
</li>
{% endif %}

{%- if nav_item.children %}
<li class="children">
	<ul class="sub-nav">
		{%- set navlevel = navlevel + 1 %}
		{%- for nav_item in nav_item.children %}
		{% include 'html/nav-item2.html' %}
		{%- endfor %}
		{%- set navlevel = navlevel - 1 %}
	</ul>
</li>
{% endif %}