.search-container {
  margin-bottom: 40px;
  padding: 0;
}

.search-input {
  border: 0px;
  width: 100%;
  margin: auto;
  padding: 5px;
}

.search-results {
  border: 0px;
  max-width: 800px;
}

.search-results p {
    margin-top: 15px;
}

article {
  background-color: black;
  padding: 15px;
  padding-bottom: 25px;
  margin: auto;
}
